@@ -1,5 +1,7 @@
 //! Protocol logic specific to processing ICS2 messages of type `MsgUpdateAnyClient`.
 
+use core::convert::From;
+use tendermint::Time;
 use tracing::debug;
 
 use crate::core::ics02_client::client_consensus::AnyConsensusState;
@@ -27,6 +29,7 @@ pub struct Result {
 }
 
 pub fn process(
+    now: Time,
     ctx: &dyn ClientReader,
     msg: MsgUpdateAnyClient,
 ) -> HandlerResult<ClientResult, Error> {
@@ -59,12 +62,12 @@ pub fn process(
 
     debug!("latest consensus state: {:?}", latest_consensus_state);
 
-    let duration = Timestamp::now()
+    let duration = Timestamp::from(now)
         .duration_since(&latest_consensus_state.timestamp())
         .ok_or_else(|| {
             Error::invalid_consensus_state_timestamp(
                 latest_consensus_state.timestamp(),
-                header.timestamp(),
+                Timestamp::from(now),
             )
         })?;
 
@@ -79,7 +82,7 @@ pub fn process(
     // This function will return the new client_state (its latest_height changed) and a
     // consensus_state obtained from header. These will be later persisted by the keeper.
     let (new_client_state, new_consensus_state) = client_def
-        .check_header_and_update_state(ctx, client_id.clone(), client_state, header)
+        .check_header_and_update_state(now, ctx, client_id.clone(), client_state, header)
         .map_err(|e| Error::header_verification_failure(e.to_string()))?;
 
     let result = ClientResult::Update(Result {
@@ -100,6 +103,7 @@ pub fn process(
 #[cfg(test)]
 mod tests {
     use core::str::FromStr;
+    use tendermint::Time;
     use test_log::test;
 
     use crate::core::ics02_client::client_consensus::AnyConsensusState;
@@ -139,7 +143,7 @@ mod tests {
             signer,
         };
 
-        let output = dispatch(&ctx, ClientMsg::UpdateClient(msg.clone()));
+        let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg.clone()));
 
         match output {
             Ok(HandlerOutput {
@@ -186,7 +190,7 @@ mod tests {
             signer,
         };
 
-        let output = dispatch(&ctx, ClientMsg::UpdateClient(msg.clone()));
+        let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg.clone()));
 
         match output {
             Err(Error(ErrorDetail::ClientNotFound(e), _)) => {
@@ -222,7 +226,7 @@ mod tests {
                 signer: signer.clone(),
             };
 
-            let output = dispatch(&ctx, ClientMsg::UpdateClient(msg.clone()));
+            let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg.clone()));
 
             match output {
                 Ok(HandlerOutput {
@@ -289,7 +293,7 @@ mod tests {
             signer,
         };
 
-        let output = dispatch(&ctx, ClientMsg::UpdateClient(msg.clone()));
+        let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg.clone()));
 
         match output {
             Ok(HandlerOutput {
@@ -366,7 +370,7 @@ mod tests {
             signer,
         };
 
-        let output = dispatch(&ctx, ClientMsg::UpdateClient(msg.clone()));
+        let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg.clone()));
 
         match output {
             Ok(HandlerOutput {
@@ -446,7 +450,7 @@ mod tests {
             signer,
         };
 
-        let output = dispatch(&ctx, ClientMsg::UpdateClient(msg.clone()));
+        let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg.clone()));
 
         match output {
             Ok(HandlerOutput {
@@ -520,7 +524,7 @@ mod tests {
             signer,
         };
 
-        let output = dispatch(&ctx, ClientMsg::UpdateClient(msg));
+        let output = dispatch(Time::now(), &ctx, ClientMsg::UpdateClient(msg));
 
         match output {
             Ok(_) => {
