@@ -92,6 +92,8 @@ impl From<MockClientState> for RawMockClientState {
 }
 
 impl ClientState for MockClientState {
+    type UpgradeOptions = ();
+
     fn chain_id(&self) -> ChainId {
         todo!()
     }
@@ -108,6 +110,10 @@ impl ClientState for MockClientState {
         self.frozen_height
     }
 
+    fn upgrade(self, _upgrade_height: Height, _upgrade_options: (), _chain_id: ChainId) -> Self {
+        todo!()
+    }
+
     fn wrap_any(self) -> AnyClientState {
         AnyClientState::Mock(self)
     }
@@ -181,10 +187,6 @@ impl ConsensusState for MockConsensusState {
         &self.root
     }
 
-    fn validate_basic(&self) -> Result<(), Infallible> {
-        Ok(())
-    }
-
     fn wrap_any(self) -> AnyConsensusState {
         AnyConsensusState::Mock(self)
     }
